@@ -1,13 +1,15 @@
 from prose import  Block
 from prose.blocks.psf import *
+from prose.utils import register_args
 from astropy.stats import SigmaClip
 from photutils.background import Background2D, MedianBackground
 
 
 class PhotutilsBackground2D(Block):
 
-    def __init__(self, subtract=True, **kwargs):
-        super().__init__(**kwargs)
+    
+    def __init__(self, subtract=True, name=None):
+        super().__init__(name=None)
         self.sigma_clip = SigmaClip(sigma=3.)
         self.bkg_estimator = MedianBackground()
         self.subtract = subtract
