@@ -8,8 +8,7 @@ from astropy.coordinates import Angle
 from dateutil import parser as dparser
 from astropy.wcs import WCS
 from . import viz, utils, Telescope
-from .utils import easy_median
-from .console_utils import info
+from .utils import gaia_query
 
 from astropy.io import fits
 from datetime import timedelta
@@ -53,10 +52,12 @@ class Image:
 
     """
 
-    def __init__(self, fitspath=None, data=None, header=None, **kwargs):
+    def __init__(self, fitspath=None, data=None, header=None, verbose=True, telescope=None, **kwargs):
         """
         Image instanciation
         """
+        self.verbose = verbose
+
         if fitspath is not None:
             self.path = fitspath
             self._get_data_header()
@@ -68,7 +69,10 @@ class Image:
         self.telescope = None
         self.discard = False
         self.__dict__.update(kwargs)
-        self._check_telescope()
+        if telescope is None:
+            self._check_telescope()
+        else:
+            self.telescope = Telescope.from_name(telescope)
         self.catalogs = {}
 
     def _get_data_header(self):
@@ -90,7 +94,12 @@ class Image:
         Image
             copied object
         """
-        new_self = self.__class__(**self.__dict__)
+        d = self.__dict__.copy()
+        d["telescope"] = self.telescope.name
+        new_self = self.__class__(**d)
+        new_self.data = new_self.data.copy()
+        new_self.header = new_self.header.copy()
+        new_self.catalogs = self.catalogs.copy()
         if not data:
             del new_self.__dict__["data"]
 
@@ -100,7 +109,11 @@ class Image:
         """Instantiate ``self.telescope`` from ``INSTRUME`` and or ``TELESCOP`` keywords
         """
         if self.header:
-           self.telescope = Telescope.from_names(self.header.get("INSTRUME", ""), self.header.get("TELESCOP", ""))
+           self.telescope = Telescope.from_names(
+               self.header.get("INSTRUME", ""), 
+               self.header.get("TELESCOP", ""), 
+               verbose=self.verbose
+            )
 
     def get(self, key, default=None):
         """Return corresponding value from header, similar to ``dict.get``
@@ -283,6 +296,8 @@ class Image:
         zscale=True,
         frame=False,
         contrast=0.1,
+        ms=15,
+        fs=12,
         **kwargs
         ):
         """Show image data
@@ -305,6 +320,10 @@ class Image:
             whether to show astronomical coordinates axes, by default False
         contrast : float, optional
             image contrast used in image scaling, by default 0.1
+        ms: int
+            stars markers size
+        ft: int
+            stars label font size
 
         See also
         --------
@@ -337,9 +356,9 @@ class Image:
         if stars is None:
             stars = "stars_coords" in self.__dict__
         
-        if stars:
+        if stars and self.stars_coords is not None:
             label = np.arange(len(self.stars_coords)) if stars_labels else None
-            viz.plot_marks(*self.stars_coords.T, label=label, ax=ax)
+            viz.plot_marks(*self.stars_coords.T, label=label, ax=ax, ms=ms, offset=0.5*ms, fontsize=fs)
 
         if frame:
             overlay = ax.get_coords_overlay(self.wcs)
@@ -385,13 +404,13 @@ class Image:
 
     @property
     def fov(self):
-        """Field of view of the image in degrees
+        """RA-DEC field of view of the image in degrees
 
         Returns
         -------
         astropy.units Quantity
         """
-        return np.array(self.shape) * self.pixel_scale.to(u.deg)
+        return np.array(self.shape)[::-1] * self.pixel_scale.to(u.deg)
 
     @property
     def pixel_scale(self):
@@ -423,7 +442,7 @@ class Image:
         else:
             raise ValueError("center type not understood")
 
-        search_radius = 60 * arcmin / self.telescope.pixel_scale
+        search_radius = (60 * arcmin * u.arcmin / self.pixel_scale).decompose().value
         circle = plt.Circle((x, y), search_radius, fill=None, ec="white", alpha=0.6)
 
         ax = plt.gca()
@@ -462,3 +481,75 @@ class Image:
         hdu = fits.PrimaryHDU(data=self.data, header=fits.Header(utils.clean_header(self.header)))
         hdu.writeto(destination, overwrite=True)
 
+    def gaia_stars(self, world=False, inplace=True):
+        """Query gaia stars in the image  (only in >= 2.0.3)
+
+        Parameters
+        ----------
+        world : bool, optional
+            wether to return coordinates as SkyCoord if inplace is False, by default False which return the pixel location of stars in image
+        inplace : bool, optional
+            wether to set set Image.stars_coords to pixel coordinates of stars instead of returning them, by default True
+        """
+        fovmax = np.max(self.fov)
+        fov = u.Quantity([fovmax, fovmax])
+        stars_radec = gaia_query(self.skycoord, fov, "ra", "dec", circular=False).to_pandas().values
+        stars_worlds = SkyCoord(*stars_radec.T, unit=("deg", "deg"))
+        stars_coords = np.array(self.wcs.world_to_pixel(stars_worlds)).T
+        
+        if not inplace:
+            if world:
+                return stars_worlds
+            else:
+                return stars_coords
+        else:
+            self.stars_coords = stars_coords
+            
+    def plot_marks(self, coordinates, label=None, ax=None, **kwargs):
+        """Plot circular marks given world coordinates (only in >= 2.0.3)
+
+        Parameters
+        ----------
+        coordinates : _type_
+            _description_
+        label : _type_, optional
+            _description_, by default None
+        ax : _type_, optional
+            _description_, by default None
+
+        Example
+        -------
+
+        .. jupyter-execute::
+
+            from prose import archive
+            import matplotlib.pyplot as plt
+
+            # star coordinates
+            coord = "04 27 01.36232", "-28 12 48.21681"
+
+            # getting an archival image for example
+            field_of_view = [3, 1.5] 
+            image = archive.pos1_image(coord, field_of_view)
+
+            # overplotting coord on image
+            image.show()
+            plt.title(image.date.date())
+            image.plot_marks(coord, color="k", ms=15)
+
+        """
+        
+        if len(np.shape(coordinates)) == 1:
+            coordinates = utils.check_skycoord(coordinates)
+        
+        if isinstance(coordinates, SkyCoord):
+            stars_coords = np.array(self.wcs.world_to_pixel(coordinates)).T
+        else:
+            stars_coords = coordinates
+        
+        label = np.arange(len(stars_coords)) if label is True else None
+        
+        if ax is None:
+            ax = plt.gca()
+            
+        viz.plot_marks(*stars_coords.T, label=label, ax=ax, **kwargs)
\ No newline at end of file
