@@ -83,13 +83,13 @@ class Photometry:
         self.photometry = photometry(**kwargs)
         self.show = show
 
-    def run(self, destination):
+    def run(self, destination,**kwargs):
         self._check_phot_path(destination)
 
         # Reference detection
         # -------------------
         self.detection_s = Sequence([
-            blocks.DAOFindStars(n_stars=self.n_stars, name="detection"),
+            blocks.DAOFindStars(n_stars=self.n_stars, name="detection",**kwargs),
             blocks.Set(stars_coords=self.stars) if self.stars is not None else blocks.Pass(),
             blocks.Cutouts(size=51),
             blocks.MedianPSF(),
@@ -126,7 +126,8 @@ class Photometry:
                 (("time", "apertures", "star"), "errors"),
                 (("time", "apertures", "star"), "apertures_area"),
                 (("time", "apertures", "star"), "apertures_radii"),
-                (("time", "star"), "sky"),
+                (("time", "star"), "annulus_sky"),
+                ("time", "sky"),
                 (("time", "apertures"), "apertures_area"),
                 (("time", "apertures"), "apertures_radii"),
                 ("time", "annulus_rin"),
@@ -152,8 +153,6 @@ class Photometry:
         xarray = xr.merge([phot_xarray,initial_xarray], combine_attrs="no_conflicts", join='left', compat='override')
         xarray = xarray.transpose("apertures", "star", "time", ...)
         xarray = xarray.assign_coords(stars=(("star", "n"), self.stars))
-        xarray["apertures_sky"] = xarray.sky  # mean over stars
-        xarray["sky"] = ("time", np.mean(xarray.apertures_sky.values, 0))  # mean over stars
         xarray.attrs["photometry"] = [b.__class__.__name__ for b in self.photometry_s.blocks]
         xarray.attrs["photometry_prose_version"] = __version__
         xarray.to_netcdf(self.phot)
