@@ -10,6 +10,7 @@ import shutil
 from pathlib import Path
 from prose import Telescope, blocks, load
 from prose.reports import Report, Summary
+from prose.utils import register
 
 
 RAW = Path("synthetic_dataset")
@@ -66,7 +67,7 @@ class TestFitsManager(unittest.TestCase):
 
 class TestReduction(unittest.TestCase):
 
-    def test_reduction(self):
+    def test_OLD_reduction(self):
         
         # generate dataset
         import numpy as np
@@ -107,6 +108,27 @@ class TestReduction(unittest.TestCase):
 
         shutil.rmtree(RAW)
 
+    def test_OLD_empty_calibration(self):
+    
+        # generate dataset
+        import numpy as np
+        from prose.tutorials import simulate_observation
+
+        time = np.linspace(0, 0.15, 10) + 2450000
+        target_dflux = 1 + np.sin(time*100)*1e-2
+        simulate_observation(time, target_dflux, RAW)
+        
+        Telescope({
+            "name": "fake_telescope",
+            "trimming": (0, 0),
+            "latlong": [24.6275, 70.4044]
+        })
+
+        fm = FitsManager(RAW, depth=2)
+        destination = fm.obs_name
+        calib = Calibration(bias=[], darks=[], flats=[], overwrite=True)
+        calib.run(fm.images, TEST_FODLER / destination)
+
 class TestObservation(unittest.TestCase):
 
     def __init__(self, *args, **kwargs):
@@ -205,5 +227,48 @@ class TestObservation(unittest.TestCase):
         plt.savefig(result_file)
         plt.close()
 
+class TestRegisterArgs(unittest.TestCase):
+
+    def __init__(self, *args, **kwargs):
+        unittest.TestCase.__init__(self, *args, **kwargs)
+
+    def test_register_args(self):
+        class Test:
+            def __init__(self, a, b):
+                register(locals())
+                self.a = a
+
+        t = Test(2, 3)
+        print("{'a': 2, 'b': 3} {}")
+        print(t.args, t.kwargs, "\n")
+
+        class Test:
+            def __init__(self, a, b=4):
+                register(locals())
+                self.a = a
+                
+        t = Test(2, 3)
+        print("{'a': 2} {'b': 3}")
+        print(t.args, t.kwargs, "\n")
+
+        class Test:
+            def __init__(self, a, *args):
+                register(locals())
+                self.a = a
+                
+        t = Test(2, 5)
+        print("{'a': 2, '0': 5} {}")
+        print(t.args, t.kwargs, "\n")
+
+        class Test:
+            def __init__(self, a, **kwargs):
+                register(locals())
+                self.a = a
+                
+        t = Test(2, g=5)
+        print("{'a': 2} {'g': 5}")
+        print(t.args, t.kwargs, "\n")
+
+
 if __name__ == "__main__":
     unittest.main()
\ No newline at end of file
